CypherDocument class final
A parsed Cypher document containing one or more statements.
- Inheritance
-
- Object
- CypherNode
- CypherDocument
- Annotations
-
- @immutable
Constructors
-
CypherDocument({required SourceSpan span, required List<
CypherStatement> statements}) -
Creates a document node.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → SourceSpan
-
The source span for this node in the original query.
finalinherited
-
statements
→ List<
CypherStatement> -
The statements included in this document.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited