UnionClause class final

A UNION or UNION ALL clause separating query parts.

Inheritance
Annotations
  • @immutable

Constructors

UnionClause({required SourceSpan span, required String queryPart, bool all = false})
Creates a union clause.
const

Properties

all bool
Whether this clause is UNION ALL.
final
body String
The raw clause body text.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
keyword String
The normalized clause keyword, such as MATCH.
finalinherited
queryPart String
The following query part text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source span for this node in the original query.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited