WithClause class final

Inheritance
Annotations
  • @immutable

Constructors

WithClause({required SourceSpan span, required String items})
const

Properties

body String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
items String
final
keyword String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited