CypherClause class sealed
A base node type for Cypher clauses.
- Inheritance
-
- Object
- CypherNode
- CypherClause
- Implementers
- Annotations
-
- @immutable
Properties
- body → String
-
The raw clause body text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyword → String
-
The normalized clause keyword, such as
MATCH.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → SourceSpan
-
The source span for this node in the original query.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited