ReturnClause class final
A RETURN clause.
- Inheritance
-
- Object
- CypherNode
- CypherClause
- ReturnClause
- Annotations
-
- @immutable
Constructors
- ReturnClause({required SourceSpan span, required String items})
-
Creates a return clause.
const
Properties
- body → String
-
The raw clause body text.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- items → String
-
The projection items text.
final
- keyword → String
-
The normalized clause keyword, such as
MATCH.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → SourceSpan
-
The source span for this node in the original query.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited